@@ -52,7 +52,7 @@ class Freebox(IPlugin):
 			if rs['ids'] == idex :
 				log.msg("*************  TROUVé ****************")
 				if rs['idx_sec'] <> "1":
-					log.msg("*************  'idx_sec'] <> "1" ****************")
+					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre  
 					# search position '|' dans rs['idx']	
 					bodies = rs['boy']
@@ -63,7 +63,7 @@ class Freebox(IPlugin):
 						resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 						log.msg("resp  :  %s" % (resp))
 				else:
-					log.msg("*************  'idx_sec'] = "1" ****************")
+					log.msg("*************  'idx_sec'] = 1 ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 				
 				
