@@ -15,7 +15,7 @@ from lisa.plugins.Freebox.modules.freebox import Freebox
 @login_required()
 def index(request):
 
-    return render_to_response(os.path.abspath(os.path.dirname(__file__) + '/templates/Freebox-index.html'),
+    return render_to_response(os.path.abspath(os.path.dirname(__file__) + '/templates/freebox-index.html'),
                               {
                                   'content': 'test'
                               },
